EXSWHTEC-251 - Implement Performance Tests for Stream APIs (#142)
Change-Id: I790d8cadb3a94a220a52c8bdc0a23b1a63931232
This commit is contained in:
committed by
Maneesh Gupta
parent
615ac6b9ad
commit
f05f97758e
@@ -0,0 +1,87 @@
|
||||
/*
|
||||
Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
|
||||
Permission is hereby granted, free of charge, to any person obtaining a copy
|
||||
of this software and associated documentation files (the "Software"), to deal
|
||||
in the Software without restriction, including without limitation the rights
|
||||
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
||||
copies of the Software, and to permit persons to whom the Software is
|
||||
furnished to do so, subject to the following conditions:
|
||||
The above copyright notice and this permission notice shall be included in
|
||||
all copies or substantial portions of the Software.
|
||||
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
|
||||
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
||||
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
||||
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
|
||||
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
||||
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||
THE SOFTWARE.
|
||||
*/
|
||||
|
||||
#include "mem_pools_performance_common.hh"
|
||||
|
||||
/**
|
||||
* @addtogroup stream stream
|
||||
* @{
|
||||
* @ingroup PerformanceTest
|
||||
*/
|
||||
|
||||
class MemPoolImportPointerBenchmark : public Benchmark<MemPoolImportPointerBenchmark> {
|
||||
public:
|
||||
void operator()(const size_t array_size) {
|
||||
float* device_ptr{nullptr};
|
||||
float* device_ptr_import{nullptr};
|
||||
hipMemPool_t mem_pool{nullptr};
|
||||
hipMemPoolPtrExportData exp_data;
|
||||
|
||||
hipMemPoolProps props = CreateMemPoolProps(0, kHandleType);
|
||||
HIP_CHECK(hipMemPoolCreate(&mem_pool, &props));
|
||||
HIP_CHECK(hipMallocFromPoolAsync(&device_ptr, array_size * sizeof(float), mem_pool, nullptr));
|
||||
HIP_CHECK(hipStreamSynchronize(nullptr));
|
||||
HIP_CHECK(hipMemPoolExportPointer(&exp_data, device_ptr));
|
||||
|
||||
TIMED_SECTION(kTimerTypeCpu) {
|
||||
HIP_CHECK(hipMemPoolImportPointer(reinterpret_cast<void**>(device_ptr_import), mem_pool, &exp_data));
|
||||
}
|
||||
|
||||
HIP_CHECK(hipFree(device_ptr));
|
||||
HIP_CHECK(hipFree(device_ptr_import));
|
||||
HIP_CHECK(hipMemPoolDestroy(mem_pool));
|
||||
}
|
||||
};
|
||||
|
||||
static void RunBenchmark(const size_t array_size) {
|
||||
MemPoolImportPointerBenchmark benchmark;
|
||||
benchmark.AddSectionName(std::to_string(array_size));
|
||||
benchmark.Run(array_size);
|
||||
}
|
||||
|
||||
/**
|
||||
* @warning **MemPool APIs are not fully implemented within current version
|
||||
* or HIP and therefore they cannot be appropriately executed on AMD and NVIDIA platforms.
|
||||
* Therefore, all tests related to MemPool APIs are implemented without formal
|
||||
* verification and will be verified once HIP fully supports MemPool APIs.**
|
||||
* Test Description
|
||||
* ------------------------
|
||||
* - Executes `hipMemPoolImportPointer`:
|
||||
* -# Allocation size:
|
||||
* - 4 KB
|
||||
* - 4 MB
|
||||
* - 16 MB
|
||||
* - Uses the same process for import and export operations.
|
||||
* Test source
|
||||
* ------------------------
|
||||
* - performance/stream/hipMemPoolImportPointer.cc
|
||||
* Test requirements
|
||||
* ------------------------
|
||||
* - Device supports memory pools
|
||||
* - HIP_VERSION >= 5.2
|
||||
*/
|
||||
TEST_CASE("Performance_hipMemPoolImportPointer") {
|
||||
if (!AreMemPoolsSupported(0)) {
|
||||
HipTest::HIP_SKIP_TEST("GPU 0 doesn't support hipDeviceAttributeMemoryPoolsSupported "
|
||||
"attribute. Hence skipping the testing with Pass result.\n");
|
||||
return;
|
||||
}
|
||||
size_t array_size = GENERATE(4_KB, 4_MB, 16_MB);
|
||||
RunBenchmark(array_size);
|
||||
}
|
||||
Reference in New Issue
Block a user